package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.ManageDeviceDictionary;
import com.ruoyi.system.dto.DroneMark;
import com.ruoyi.system.service.IManageDeviceDictionaryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.VideoInfo;
import com.ruoyi.system.service.IVideoInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 视频设备Controller
 *
 * @author ruoyi
 * @date 2024-07-15
 */
@RestController
@Api(tags = "设备管理")
@RequestMapping("/system/info")
public class VideoInfoController extends BaseController
{
    @Autowired
    private IVideoInfoService videoInfoService;
    @Autowired
    private IManageDeviceDictionaryService manageDeviceDictionaryService;

    /**
     * 查询视频设备列表
     */
    // @PreAuthorize("@ss.hasPermi('system:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(VideoInfo videoInfo)
    {
        startPage();
        List<VideoInfo> list = videoInfoService.selectVideoInfoList(videoInfo);
        // 遍历list设备列表
        for (VideoInfo video : list) {
            // 得到的值是这样的 3-2-1
            String deviceType = video.getDeviceType();
            // 拆分出来
            String[] split = deviceType.split("-");
            ManageDeviceDictionary manageDeviceDictionary = manageDeviceDictionaryService.selectManageDeviceDictionaryByCondition(split[0], split[1], split[2]);
            video.setRemark(video.getDeviceType());
            video.setDeviceType(manageDeviceDictionary.getDeviceName());
        }


        return getDataTable(list);
    }

    /**
     * 导出视频设备列表
     */
    // @PreAuthorize("@ss.hasPermi('system:info:export')")
    @Log(title = "视频设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VideoInfo videoInfo)
    {
        List<VideoInfo> list = videoInfoService.selectVideoInfoList(videoInfo);
        ExcelUtil<VideoInfo> util = new ExcelUtil<VideoInfo>(VideoInfo.class);
        util.exportExcel(response, list, "视频设备数据");
    }

    /**
     * 获取视频设备详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(videoInfoService.selectVideoInfoById(id));
    }

    /**
     * 新增视频设备
     */
    // @PreAuthorize("@ss.hasPermi('system:info:add')")
    @Log(title = "视频设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody VideoInfo videoInfo)
    {
        return toAjax(videoInfoService.insertVideoInfo(videoInfo));
    }

    /**
     * 修改视频设备
     */
    // @PreAuthorize("@ss.hasPermi('system:info:edit')")
    @Log(title = "视频设备", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody VideoInfo videoInfo)
    {
        return toAjax(videoInfoService.updateVideoInfo(videoInfo));
    }

    /**
     * 删除视频设备
     */
    // @PreAuthorize("@ss.hasPermi('system:info:remove')")
    @Log(title = "视频设备", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(videoInfoService.deleteVideoInfoByIds(ids));
    }

    /**
     * 查询机场设备列表
     */
    @GetMapping("/droneList")
    public TableDataInfo droneList() {
        startPage();
        VideoInfo videoInfo = new VideoInfo();
        videoInfo.setType("机场");
        List<VideoInfo> list = videoInfoService.selectVideoInfoList(videoInfo);
        return getDataTable(list);
    }
}
